@@ -2,9 +2,10 @@ package Dancer::Plugin::RPC::RESTISH;
 use v5.10;
 use Dancer ':syntax';
 use Dancer::Plugin;
-use Time::HiRes 'time';
 
-our $VERSION = '1.01_01';
+no if $] >= 5.018, warnings => 'experimental::smartmatch';
+
+our $VERSION = '1.01';
 
 use constant PLUGIN_NAME => 'restish';
 
@@ -51,16 +52,14 @@ register PLUGIN_NAME ,=> sub {
     my @allowed_origins = split(' ', $allow_origin);
 
     my $publisher;
-    GIVEN: {
-        local $_ = $arguments->{publish} // 'config';
-        exists($dispatch_builder_map{$_}) && do {
+    given ($arguments->{publish} // 'config') {
+        when (exists $dispatch_builder_map{$_}) {
             $publisher = $dispatch_builder_map{$_};
             $arguments->{arguments} = plugin_setting() if $_ eq 'config';
-            last GIVEN;
-        };
-        do {
+        }
+        default {
             $publisher = $_;
-        };
+        }
     }
     my $dispatcher = $publisher->($arguments->{arguments}, $endpoint);
 
@@ -192,7 +191,6 @@ register PLUGIN_NAME ,=> sub {
         };
         debug("[handling_restish_request('$request_path' via '$found_match')] ", $method_args);
 
-        my $start_request = time();
         my Dancer::RPCPlugin::CallbackResult $continue = eval {
             (my $match_re = $found_match) =~ s{:\w+}{[^/]+}g;
             local $Dancer::RPCPlugin::ROUTE_INFO = {
@@ -272,10 +270,6 @@ register PLUGIN_NAME ,=> sub {
             $jsonise_options->{utf8} = 1;
         }
 
-        info( sprintf(
-            "[RPC::RESTISH] request for %s took %.4fs",
-            $request_path, time() - $start_request
-        ));
         # non-refs will be send as-is
         return ref($response)
             ? to_json($response, $jsonise_options)
